"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.builds.build_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildInitDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SPEC_FIELD_NUMBER: builtins.int
    INITIATOR_FIELD_NUMBER: builtins.int
    @property
    def build_spec(self) -> qwak.builds.build_pb2.RemoteBuildSpec:
        """Requested build model spec"""
    @property
    def initiator(self) -> qwak.builds.build_pb2.BuildInitiator:
        """override to the initiator of the build"""
    def __init__(
        self,
        *,
        build_spec: qwak.builds.build_pb2.RemoteBuildSpec | None = ...,
        initiator: qwak.builds.build_pb2.BuildInitiator | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec", "initiator", b"initiator"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec", "initiator", b"initiator"]) -> None: ...

global___BuildInitDetails = BuildInitDetails

class InternalBuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_INIT_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def build_init_details(self) -> global___BuildInitDetails:
        """The request of build"""
    def __init__(
        self,
        *,
        build_init_details: global___BuildInitDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_init_details", b"build_init_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_init_details", b"build_init_details"]) -> None: ...

global___InternalBuildModelRequest = InternalBuildModelRequest

class InternalBuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InternalBuildModelResponse = InternalBuildModelResponse
