"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.fitness_service.fitness_pb2
import qwak.fitness_service.status_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SPEC_FIELD_NUMBER: builtins.int
    @property
    def build_spec(self) -> qwak.fitness_service.fitness_pb2.BuildSpec:
        """Requested build model spec"""
    def __init__(
        self,
        *,
        build_spec: qwak.fitness_service.fitness_pb2.BuildSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> None: ...

global___BuildModelRequest = BuildModelRequest

class BuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BuildModelResponse = BuildModelResponse

class CancelBuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Build id of the build to cancel"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CancelBuildModelRequest = CancelBuildModelRequest

class CancelBuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelBuildModelResponse = CancelBuildModelResponse

class GetRemoteBuildingStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Build id of the build to get status for"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___GetRemoteBuildingStatusRequest = GetRemoteBuildingStatusRequest

class GetRemoteBuildingStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> qwak.fitness_service.status_pb2.RemoteBuildingStatus: ...
    def __init__(
        self,
        *,
        status: qwak.fitness_service.status_pb2.RemoteBuildingStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___GetRemoteBuildingStatusResponse = GetRemoteBuildingStatusResponse

class CleanRemoteBuildResourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CleanRemoteBuildResourcesRequest = CleanRemoteBuildResourcesRequest

class CleanRemoteBuildResourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CleanRemoteBuildResourcesResponse = CleanRemoteBuildResourcesResponse
