"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.feature_store.jobs.v1.job_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DeleteFeaturesetJobByJobIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """Featureset id"""
    environment_id: builtins.str
    """Environment id"""
    job_id: builtins.str
    """Job id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id", "job_id", b"job_id"]) -> None: ...

global___DeleteFeaturesetJobByJobIdRequest = DeleteFeaturesetJobByJobIdRequest

class DeleteFeaturesetJobByJobIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_JOB_RECORD_COUNT_FIELD_NUMBER: builtins.int
    deleted_job_record_count: builtins.int
    def __init__(
        self,
        *,
        deleted_job_record_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_job_record_count", b"deleted_job_record_count"]) -> None: ...

global___DeleteFeaturesetJobByJobIdResponse = DeleteFeaturesetJobByJobIdResponse

class ApplyJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORD_FIELD_NUMBER: builtins.int
    @property
    def job_record(self) -> qwak.feature_store.jobs.v1.job_pb2.JobRecord:
        """The job record to register"""
    def __init__(
        self,
        *,
        job_record: qwak.feature_store.jobs.v1.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> None: ...

global___ApplyJobRequest = ApplyJobRequest

class ApplyJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RUNNING_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    job_running_id: builtins.int
    """Job running id"""
    job_id: builtins.str
    """Job Id"""
    def __init__(
        self,
        *,
        job_running_id: builtins.int = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id", "job_running_id", b"job_running_id"]) -> None: ...

global___ApplyJobResponse = ApplyJobResponse

class InitPaginationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested job records"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___InitPaginationRequest = InitPaginationRequest

class InitPaginationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    PAGINATION_SESSION_MAX_ID_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """The amount of records that exist for this pagination session (current total amount of records for the featureset)"""
    pagination_session_max_id: builtins.int
    """The record to use for the max pagination sessions id in the ListJobs request"""
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        pagination_session_max_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination_session_max_id", b"pagination_session_max_id", "record_count", b"record_count"]) -> None: ...

global___InitPaginationResponse = InitPaginationResponse

class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    PAGINATION_SESSION_MAX_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested job records"""
    environment_id: builtins.str
    """Environment id"""
    page_size: builtins.int
    """The amount of records to send in the result set"""
    page_number: builtins.int
    """The page number to get"""
    pagination_session_max_id: builtins.int
    """The max session record id from which we retrieve the data, if unset (defaults to 0) we return the first records"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        pagination_session_max_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id", "page_number", b"page_number", "page_size", b"page_size", "pagination_session_max_id", b"pagination_session_max_id"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.v1.job_pb2.JobRecord]:
        """Result set of the requested jobs"""
    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[qwak.feature_store.jobs.v1.job_pb2.JobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs", b"jobs"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

class GetLatestSuccessfulJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested latest successful job record"""
    environment_id: builtins.str
    """The jobs' environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___GetLatestSuccessfulJobRequest = GetLatestSuccessfulJobRequest

class GetLatestJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested latest job record running"""
    environment_id: builtins.str
    """The jobs' environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___GetLatestJobRequest = GetLatestJobRequest

class GetLatestJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> qwak.feature_store.jobs.v1.job_pb2.JobRecord:
        """the requested job"""
    def __init__(
        self,
        *,
        job: qwak.feature_store.jobs.v1.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job", b"job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["job", b"job"]) -> None: ...

global___GetLatestJobResponse = GetLatestJobResponse

class GetLatestSuccessfulJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    FOUND_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> qwak.feature_store.jobs.v1.job_pb2.JobRecord:
        """the requested job"""
    found: builtins.bool
    """is the job empty or not"""
    def __init__(
        self,
        *,
        job: qwak.feature_store.jobs.v1.job_pb2.JobRecord | None = ...,
        found: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job", b"job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["found", b"found", "job", b"job"]) -> None: ...

global___GetLatestSuccessfulJobResponse = GetLatestSuccessfulJobResponse

class GetAllLatestSuccessfulJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAllLatestSuccessfulJobsRequest = GetAllLatestSuccessfulJobsRequest

class GetAllLatestSuccessfulJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.v1.job_pb2.JobRecord]:
        """all latest requested jobs"""
    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[qwak.feature_store.jobs.v1.job_pb2.JobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs", b"jobs"]) -> None: ...

global___GetAllLatestSuccessfulJobsResponse = GetAllLatestSuccessfulJobsResponse

class DeleteFeaturesetJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested delete featureset jobs"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___DeleteFeaturesetJobsRequest = DeleteFeaturesetJobsRequest

class DeleteFeaturesetJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_JOB_RECORDS_COUNT_FIELD_NUMBER: builtins.int
    deleted_job_records_count: builtins.int
    def __init__(
        self,
        *,
        deleted_job_records_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_job_records_count", b"deleted_job_records_count"]) -> None: ...

global___DeleteFeaturesetJobsResponse = DeleteFeaturesetJobsResponse

class GetJobsSummariesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOWER_TIME_BOUND_FIELD_NUMBER: builtins.int
    UPPER_TIME_BOUND_FIELD_NUMBER: builtins.int
    @property
    def lower_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Summary lower time bound"""
    @property
    def upper_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        lower_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        upper_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "upper_bound", b"upper_bound", "upper_time_bound", b"upper_time_bound"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "upper_bound", b"upper_bound", "upper_time_bound", b"upper_time_bound"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["upper_bound", b"upper_bound"]) -> typing_extensions.Literal["upper_time_bound"] | None: ...

global___GetJobsSummariesRequest = GetJobsSummariesRequest

class GetJobsSummariesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_SUMMARIES_FIELD_NUMBER: builtins.int
    @property
    def jobs_summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.v1.job_pb2.FeaturesetLevelJobsSummary]:
        """Job summaries per featureset for the entire environment"""
    def __init__(
        self,
        *,
        jobs_summaries: collections.abc.Iterable[qwak.feature_store.jobs.v1.job_pb2.FeaturesetLevelJobsSummary] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs_summaries", b"jobs_summaries"]) -> None: ...

global___GetJobsSummariesResponse = GetJobsSummariesResponse
