"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class JfrogTenantDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TENANT_ID_FIELD_NUMBER: builtins.int
    DEFAULT_JFROG_PROJECT_DETAILS_FIELD_NUMBER: builtins.int
    JFROG_TENANT_CONFIGURATION_FIELD_NUMBER: builtins.int
    JPD_DETAILS_FIELD_NUMBER: builtins.int
    tenant_id: builtins.str
    """The JFrog tenant's ID"""
    @property
    def default_jfrog_project_details(self) -> global___JfrogProjectDetails:
        """JFrog project details"""
    @property
    def jfrog_tenant_configuration(self) -> global___JFrogTenantConfiguration:
        """The JFrog tenant's configuration"""
    @property
    def jpd_details(self) -> global___JPDDetails:
        """Details about this tenant id JPD"""
    def __init__(
        self,
        *,
        tenant_id: builtins.str = ...,
        default_jfrog_project_details: global___JfrogProjectDetails | None = ...,
        jfrog_tenant_configuration: global___JFrogTenantConfiguration | None = ...,
        jpd_details: global___JPDDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details", "jfrog_tenant_configuration", b"jfrog_tenant_configuration", "jpd_details", b"jpd_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details", "jfrog_tenant_configuration", b"jfrog_tenant_configuration", "jpd_details", b"jpd_details", "tenant_id", b"tenant_id"]) -> None: ...

global___JfrogTenantDetails = JfrogTenantDetails

class JPDDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SH_JPD_DETAILS_FIELD_NUMBER: builtins.int
    SAAS_JPD_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def sh_jpd_details(self) -> global___SelfHostedJPDDetails: ...
    @property
    def saas_jpd_details(self) -> global___SAASJPDDetails: ...
    def __init__(
        self,
        *,
        sh_jpd_details: global___SelfHostedJPDDetails | None = ...,
        saas_jpd_details: global___SAASJPDDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["saas_jpd_details", b"saas_jpd_details", "sh_jpd_details", b"sh_jpd_details", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["saas_jpd_details", b"saas_jpd_details", "sh_jpd_details", b"sh_jpd_details", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["sh_jpd_details", "saas_jpd_details"] | None: ...

global___JPDDetails = JPDDetails

class SelfHostedJPDDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    """The JPD base url, reachable from data planes"""
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_url", b"base_url"]) -> None: ...

global___SelfHostedJPDDetails = SelfHostedJPDDetails

class SAASJPDDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SAASJPDDetails = SAASJPDDetails

class JFrogTenantConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_JFROG_PROJECT_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def default_jfrog_project_details(self) -> global___JfrogProjectDetails:
        """JFrog project details"""
    def __init__(
        self,
        *,
        default_jfrog_project_details: global___JfrogProjectDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details"]) -> None: ...

global___JFrogTenantConfiguration = JFrogTenantConfiguration

class JfrogProjectDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_KEY_FIELD_NUMBER: builtins.int
    project_key: builtins.str
    """The JFrog project's key"""
    def __init__(
        self,
        *,
        project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_key", b"project_key"]) -> None: ...

global___JfrogProjectDetails = JfrogProjectDetails

class JfrogTenantSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TENANT_ID_FIELD_NUMBER: builtins.int
    DEFAULT_PROJECT_SPEC_FIELD_NUMBER: builtins.int
    JPD_DETAILS_SPEC_FIELD_NUMBER: builtins.int
    tenant_id: builtins.str
    """The JFrog tenant's ID"""
    @property
    def default_project_spec(self) -> global___JfrogProjectSpec:
        """The JFrog tenant's default project details"""
    @property
    def jpd_details_spec(self) -> global___JPDDetailsSpec:
        """Details about this tenant id JPD"""
    def __init__(
        self,
        *,
        tenant_id: builtins.str = ...,
        default_project_spec: global___JfrogProjectSpec | None = ...,
        jpd_details_spec: global___JPDDetailsSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_project_spec", b"default_project_spec", "jpd_details_spec", b"jpd_details_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_project_spec", b"default_project_spec", "jpd_details_spec", b"jpd_details_spec", "tenant_id", b"tenant_id"]) -> None: ...

global___JfrogTenantSpec = JfrogTenantSpec

class JPDDetailsSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SH_JPD_DETAILS_SPEC_FIELD_NUMBER: builtins.int
    SAAS_JPD_DETAILS_SPEC_FIELD_NUMBER: builtins.int
    @property
    def sh_jpd_details_spec(self) -> global___SelfHostedJPDDetailsSpec: ...
    @property
    def saas_jpd_details_spec(self) -> global___SAASJPDDetailsSpec: ...
    def __init__(
        self,
        *,
        sh_jpd_details_spec: global___SelfHostedJPDDetailsSpec | None = ...,
        saas_jpd_details_spec: global___SAASJPDDetailsSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["saas_jpd_details_spec", b"saas_jpd_details_spec", "sh_jpd_details_spec", b"sh_jpd_details_spec", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["saas_jpd_details_spec", b"saas_jpd_details_spec", "sh_jpd_details_spec", b"sh_jpd_details_spec", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["sh_jpd_details_spec", "saas_jpd_details_spec"] | None: ...

global___JPDDetailsSpec = JPDDetailsSpec

class SelfHostedJPDDetailsSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    """The JPD base url, reachable from data planes"""
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_url", b"base_url"]) -> None: ...

global___SelfHostedJPDDetailsSpec = SelfHostedJPDDetailsSpec

class SAASJPDDetailsSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SAASJPDDetailsSpec = SAASJPDDetailsSpec

class JfrogProjectSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_KEY_FIELD_NUMBER: builtins.int
    project_key: builtins.str
    """The JFrog project's key"""
    def __init__(
        self,
        *,
        project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_key", b"project_key"]) -> None: ...

global___JfrogProjectSpec = JfrogProjectSpec
