# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set_attribute.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.v1.common.source_code import source_code_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_source__code_dot_source__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/feature_store/features/feature_set_attribute.proto\x12\x1bqwak.feature.store.features\x1a:qwak/feature_store/v1/common/source_code/source_code.proto\"j\n\x14\x46\x65\x61turesetAttributes\x12R\n\x10source_code_spec\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.v1.common.source_code.SourceCodeSpecB[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')



_FEATURESETATTRIBUTES = DESCRIPTOR.message_types_by_name['FeaturesetAttributes']
FeaturesetAttributes = _reflection.GeneratedProtocolMessageType('FeaturesetAttributes', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETATTRIBUTES,
  '__module__' : 'qwak.feature_store.features.feature_set_attribute_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeaturesetAttributes)
  })
_sym_db.RegisterMessage(FeaturesetAttributes)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _FEATURESETATTRIBUTES._serialized_start=148
  _FEATURESETATTRIBUTES._serialized_end=254
# @@protoc_insertion_point(module_scope)
