# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/jobs/job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/feature_store/jobs/job.proto\x12\x17qwak.feature.store.jobs\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x02\n\tJobRecord\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x12\n\ntry_number\x18\x03 \x01(\x05\x12\x34\n\tjob_state\x18\x04 \x01(\x0e\x32!.qwak.feature.store.jobs.JobState\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x10ingestion_window\x18\x08 \x01(\x0b\x32(.qwak.feature.store.jobs.IngestionWindow\x12\x19\n\x11ingestion_message\x18\t \x01(\t\"\x85\x01\n\x12\x45laborateJobRecord\x12\x36\n\njob_record\x18\x01 \x01(\x0b\x32\".qwak.feature.store.jobs.JobRecord\x12\x16\n\x0estatus_message\x18\x02 \x01(\t\x12\x1f\n\x17\x65rror_technical_details\x18\x03 \x01(\t\"\xe9\x01\n\x0fIngestionWindow\x12<\n\x18ingested_data_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16ingested_data_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x1aingested_data_updated_rows\x18\x03 \x01(\x05\x12\x38\n\x14\x62\x61tch_execution_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*w\n\x08JobState\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x17\n\x13\x46\x41ILED_CLUSTER_INIT\x10\x05\x12\x10\n\x0c\x43LUSTER_INIT\x10\x06\x42:\n\"com.qwak.ai.feature.store.jobs.apiP\x01Z\x12qwak/fsjobs;fsjobsb\x06proto3')

_JOBSTATE = DESCRIPTOR.enum_types_by_name['JobState']
JobState = enum_type_wrapper.EnumTypeWrapper(_JOBSTATE)
INVALID = 0
PENDING = 1
RUNNING = 2
COMPLETED = 3
FAILED = 4
FAILED_CLUSTER_INIT = 5
CLUSTER_INIT = 6


_JOBRECORD = DESCRIPTOR.message_types_by_name['JobRecord']
_ELABORATEJOBRECORD = DESCRIPTOR.message_types_by_name['ElaborateJobRecord']
_INGESTIONWINDOW = DESCRIPTOR.message_types_by_name['IngestionWindow']
JobRecord = _reflection.GeneratedProtocolMessageType('JobRecord', (_message.Message,), {
  'DESCRIPTOR' : _JOBRECORD,
  '__module__' : 'qwak.feature_store.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.JobRecord)
  })
_sym_db.RegisterMessage(JobRecord)

ElaborateJobRecord = _reflection.GeneratedProtocolMessageType('ElaborateJobRecord', (_message.Message,), {
  'DESCRIPTOR' : _ELABORATEJOBRECORD,
  '__module__' : 'qwak.feature_store.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ElaborateJobRecord)
  })
_sym_db.RegisterMessage(ElaborateJobRecord)

IngestionWindow = _reflection.GeneratedProtocolMessageType('IngestionWindow', (_message.Message,), {
  'DESCRIPTOR' : _INGESTIONWINDOW,
  '__module__' : 'qwak.feature_store.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.IngestionWindow)
  })
_sym_db.RegisterMessage(IngestionWindow)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.qwak.ai.feature.store.jobs.apiP\001Z\022qwak/fsjobs;fsjobs'
  _JOBSTATE._serialized_start=837
  _JOBSTATE._serialized_end=956
  _JOBRECORD._serialized_start=96
  _JOBRECORD._serialized_end=463
  _ELABORATEJOBRECORD._serialized_start=466
  _ELABORATEJOBRECORD._serialized_end=599
  _INGESTIONWINDOW._serialized_start=602
  _INGESTIONWINDOW._serialized_end=835
# @@protoc_insertion_point(module_scope)
