# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/file_versioning/file_versioning.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/file_versioning/file_versioning.proto\x12\x1fqwak.management.file_versioning\"\xc7\x01\n\x0b\x46ileTagSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12I\n\textension\x18\x04 \x01(\x0e\x32\x32.qwak.management.file_versioning.FileExtensionTypeB\x02\x18\x01\x12\x16\n\x0e\x65xtension_type\x18\x05 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x06 \x01(\t\x12\x0c\n\x04path\x18\x07 \x01(\t\"G\n\rFileTagFilter\x12\x16\n\x0ctag_contains\x18\x01 \x01(\tH\x00\x12\x14\n\ntag_prefix\x18\x02 \x01(\tH\x00\x42\x08\n\x06\x66ilter*<\n\x11\x46ileExtensionType\x12\x0b\n\x07INVALID\x10\x00\x12\x07\n\x03PNG\x10\x01\x12\x07\n\x03JPG\x10\x02\x12\x08\n\x04JPEG\x10\x03\x42/\n+com.qwak.ai.management.model_versioning.apiP\x01\x62\x06proto3')

_FILEEXTENSIONTYPE = DESCRIPTOR.enum_types_by_name['FileExtensionType']
FileExtensionType = enum_type_wrapper.EnumTypeWrapper(_FILEEXTENSIONTYPE)
INVALID = 0
PNG = 1
JPG = 2
JPEG = 3


_FILETAGSPEC = DESCRIPTOR.message_types_by_name['FileTagSpec']
_FILETAGFILTER = DESCRIPTOR.message_types_by_name['FileTagFilter']
FileTagSpec = _reflection.GeneratedProtocolMessageType('FileTagSpec', (_message.Message,), {
  'DESCRIPTOR' : _FILETAGSPEC,
  '__module__' : 'qwak.file_versioning.file_versioning_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.file_versioning.FileTagSpec)
  })
_sym_db.RegisterMessage(FileTagSpec)

FileTagFilter = _reflection.GeneratedProtocolMessageType('FileTagFilter', (_message.Message,), {
  'DESCRIPTOR' : _FILETAGFILTER,
  '__module__' : 'qwak.file_versioning.file_versioning_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.file_versioning.FileTagFilter)
  })
_sym_db.RegisterMessage(FileTagFilter)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.management.model_versioning.apiP\001'
  _FILETAGSPEC.fields_by_name['extension']._options = None
  _FILETAGSPEC.fields_by_name['extension']._serialized_options = b'\030\001'
  _FILEEXTENSIONTYPE._serialized_start=354
  _FILEEXTENSIONTYPE._serialized_end=414
  _FILETAGSPEC._serialized_start=80
  _FILETAGSPEC._serialized_end=279
  _FILETAGFILTER._serialized_start=281
  _FILETAGFILTER._serialized_end=352
# @@protoc_insertion_point(module_scope)
